@@ -60,3 +60,13 @@ GWAS(buildOneFac(pheno, paste0("i", 1:numIndicators),
 pgen2 <- loadResults(file.path(tdir,"out.log"), "snp2F")
 
 expect_equal(cor(pgen$Z, pgen2$Z, use = "pairwise"), 1, tolerance=.15)
+
+# -----
+
+lastFit <- GWAS(buildTwoFac(pheno, paste0("i", 1:(numIndicators-1)), paste0("i", 2:numIndicators),
+                 covariates = paste0("covar",1:numCovariate)), SNP=1,
+     file.path(dir,"example.pgen"),
+     file.path(tdir,"out.log"))
+
+expect_equal(lastFit$A$labels['F1','covar1'], "covar12F1")
+expect_equal(lastFit$A$labels['i2','F1'], "F1_lambda_i2")
